pub type DBBatch = BTreeMap<Key, Option<Value>>;Expand description
We use batching to reduce the number of writes to the database
Here, a DBBatch is a map from Key to Some(Value) for a new or updated value, or None for a deletion
Aliased Type
pub struct DBBatch { /* private fields */ }